@@ -17,13 +17,17 @@ def claimMspLicence(mist_session:_APISession, msp_id:str, body:object) -> _APIRe
     """
     API doc: https://doc.mist-lab.fr/#operation/claimMspLicence
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
     :param str msp_id        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/msps/{msp_id}/claim"
     resp = mist_session.mist_post(uri=uri, body=body)
