@@ -17,7 +17,7 @@ def getMspSle(mist_session:_APISession, msp_id:str, metric:str, sle:str=None, du
     """
     API doc: https://doc.mist-lab.fr/#operation/getMspSle
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -33,6 +33,10 @@ def getMspSle(mist_session:_APISession, msp_id:str, metric:str, sle:str=None, du
     :param str interval
     :param int start
     :param int end        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/msps/{msp_id}/insights/{metric}"
     query_params={}
