@@ -17,7 +17,7 @@ def getMspInventoryByMac(mist_session:_APISession, msp_id:str, device_mac:str) -
     """
     API doc: https://doc.mist-lab.fr/#operation/getMspInventoryByMac
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -25,6 +25,10 @@ def getMspInventoryByMac(mist_session:_APISession, msp_id:str, device_mac:str) -
     -----------
     :param str msp_id
     :param str device_mac        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/msps/{msp_id}/inventory/{device_mac}"
     query_params={}
