@@ -17,7 +17,7 @@ def getOrgSitesSle(mist_session:_APISession, org_id:str, sle:str=None, start:int
     """
     API doc: https://doc.mist-lab.fr/#operation/getOrgSitesSle
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -34,6 +34,10 @@ def getOrgSitesSle(mist_session:_APISession, org_id:str, sle:str=None, start:int
     :param int page
     :param str duration
     :param str interval        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/insights/sites-sle"
     query_params={}
@@ -51,7 +55,7 @@ def getOrgSle(mist_session:_APISession, org_id:str, metric:str, sle:str=None, du
     """
     API doc: https://doc.mist-lab.fr/#operation/getOrgSle
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -67,6 +71,10 @@ def getOrgSle(mist_session:_APISession, org_id:str, metric:str, sle:str=None, du
     :param str interval
     :param int start
     :param int end        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/insights/{metric}"
     query_params={}
