@@ -17,7 +17,7 @@ def updateSdkClient(mist_session:_APISession, org_id:str, sdkclient_id:str, body
     """
     API doc: https://doc.mist-lab.fr/#operation/updateSdkClient
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -25,6 +25,10 @@ def updateSdkClient(mist_session:_APISession, org_id:str, sdkclient_id:str, body
     -----------
     :param str org_id
     :param str sdkclient_id        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/sdkclients/{sdkclient_id}"
     resp = mist_session.mist_put(uri=uri, body=body)
