@@ -13,19 +13,23 @@
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
 
-def verifyRecoverPasssword(mist_session:_APISession, token:str, body:object) -> _APIResponse:
+def verifyRecoverPasssword(mist_session:_APISession, token:str) -> _APIResponse:
     """
     API doc: https://doc.mist-lab.fr/#operation/verifyRecoverPasssword
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
     :param str token        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/recover/verify/{token}"
-    resp = mist_session.mist_post(uri=uri, body=body)
+    resp = mist_session.mist_post(uri=uri)
     return resp
     
\ No newline at end of file
