@@ -17,9 +17,13 @@ def updateSelfEmail(mist_session:_APISession, body:object) -> _APIResponse:
     """
     API doc: https://doc.mist-lab.fr/#operation/updateSelfEmail
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/self/update"
     resp = mist_session.mist_post(uri=uri, body=body)
@@ -29,13 +33,17 @@ def verifySelfEmail(mist_session:_APISession, token:str) -> _APIResponse:
     """
     API doc: https://doc.mist-lab.fr/#operation/verifySelfEmail
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
     :param str token        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/self/update/verify/{token}"
     query_params={}
