@@ -17,7 +17,7 @@ def getSiteInsightMetricsForClient(mist_session:_APISession, site_id:str, client
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteInsightMetricsForClient
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -35,6 +35,10 @@ def getSiteInsightMetricsForClient(mist_session:_APISession, site_id:str, client
     :param int end
     :param str duration
     :param str interval        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/insights/client/{client_mac}/{metric}"
     query_params={}
@@ -51,7 +55,7 @@ def getSiteInsightMetricsForDevice(mist_session:_APISession, site_id:str, metric
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteInsightMetricsForDevice
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -69,6 +73,10 @@ def getSiteInsightMetricsForDevice(mist_session:_APISession, site_id:str, metric
     :param int end
     :param str duration
     :param str interval        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/insights/device/{device_mac}/{metric}"
     query_params={}
@@ -85,7 +93,7 @@ def getSiteRogueAPs(mist_session:_APISession, site_id:str, type:str=None, limit:
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteRogueAPs
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -101,6 +109,10 @@ def getSiteRogueAPs(mist_session:_APISession, site_id:str, type:str=None, limit:
     :param int end
     :param str duration
     :param str interval        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/insights/rogues"
     query_params={}
@@ -117,7 +129,7 @@ def getSiteRogueClients(mist_session:_APISession, site_id:str, limit:int=100, st
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteRogueClients
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -132,6 +144,10 @@ def getSiteRogueClients(mist_session:_APISession, site_id:str, limit:int=100, st
     :param int end
     :param str duration
     :param str interval        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/insights/rogues/clients"
     query_params={}
@@ -147,7 +163,7 @@ def getSiteInsightMetrics(mist_session:_APISession, site_id:str, metric:str, pag
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteInsightMetrics
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -164,6 +180,10 @@ def getSiteInsightMetrics(mist_session:_APISession, site_id:str, metric:str, pag
     :param int end
     :param str duration
     :param str interval        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/insights/{metric}"
     query_params={}
