@@ -13,11 +13,11 @@
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
 
-def preemptSitesMxTunnel(mist_session:_APISession, site_id:str, mxtunnel_id:str, body:object) -> _APIResponse:
+def preemptSitesMxTunnel(mist_session:_APISession, site_id:str, mxtunnel_id:str) -> _APIResponse:
     """
     API doc: https://doc.mist-lab.fr/#operation/preemptSitesMxTunnel
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -25,8 +25,12 @@ def preemptSitesMxTunnel(mist_session:_APISession, site_id:str, mxtunnel_id:str,
     -----------
     :param str site_id
     :param str mxtunnel_id        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/mxtunnels/{mxtunnel_id}/preempt_aps"
-    resp = mist_session.mist_post(uri=uri, body=body)
+    resp = mist_session.mist_post(uri=uri)
     return resp
     
\ No newline at end of file
