@@ -17,7 +17,7 @@ def getSiteSleClassifierDetails(mist_session:_APISession, site_id:str, scope:str
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleClassifierDetails
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -25,7 +25,9 @@ def getSiteSleClassifierDetails(mist_session:_APISession, site_id:str, scope:str
     -----------
     :param str site_id
     :param str scope
-    :param str scope_id
+    :param str scope_id - * site_id if `scope`==`site`
+* device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
+* mac if `scope`==`client`
     :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics
     :param str classifier        
     
@@ -34,6 +36,10 @@ def getSiteSleClassifierDetails(mist_session:_APISession, site_id:str, scope:str
     :param int start
     :param int end
     :param str duration        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/classifier/{classifier}/summary"
     query_params={}
@@ -47,7 +53,7 @@ def getSiteSleMetricClassifiers(mist_session:_APISession, site_id:str, scope:str
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleMetricClassifiers
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -55,8 +61,14 @@ def getSiteSleMetricClassifiers(mist_session:_APISession, site_id:str, scope:str
     -----------
     :param str site_id
     :param str scope
-    :param str scope_id
+    :param str scope_id - * site_id if `scope`==`site`
+* device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
+* mac if `scope`==`client`
     :param str metric -  values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/classifiers"
     query_params={}
@@ -67,7 +79,7 @@ def getSiteSleHistogram(mist_session:_APISession, site_id:str, scope:str, scope_
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleHistogram
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -75,7 +87,9 @@ def getSiteSleHistogram(mist_session:_APISession, site_id:str, scope:str, scope_
     -----------
     :param str site_id
     :param str scope
-    :param str scope_id
+    :param str scope_id - * site_id if `scope`==`site`
+* device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
+* mac if `scope`==`client`
     :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
@@ -83,6 +97,10 @@ def getSiteSleHistogram(mist_session:_APISession, site_id:str, scope:str, scope_
     :param int start
     :param int end
     :param str duration        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/histogram"
     query_params={}
@@ -96,7 +114,7 @@ def getSiteSleImpactSummary(mist_session:_APISession, site_id:str, scope:str, sc
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleImpactSummary
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -104,7 +122,9 @@ def getSiteSleImpactSummary(mist_session:_APISession, site_id:str, scope:str, sc
     -----------
     :param str site_id
     :param str scope
-    :param str scope_id
+    :param str scope_id - * site_id if `scope`==`site`
+* device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
+* mac if `scope`==`client`
     :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
@@ -114,6 +134,10 @@ def getSiteSleImpactSummary(mist_session:_APISession, site_id:str, scope:str, sc
     :param str duration
     :param str fields(wlan, device_type, device_os, band, ap, server, mxedge, switch, client, vlan, interface, chassis, gateway, peer_path, gateway_zones)
     :param str classifier        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impact-summary"
     query_params={}
@@ -129,7 +153,7 @@ def getSiteSleImpactedApplications(mist_session:_APISession, site_id:str, scope:
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleImpactedApplications
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -146,6 +170,10 @@ def getSiteSleImpactedApplications(mist_session:_APISession, site_id:str, scope:
     :param int end
     :param str duration
     :param str classifier        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-applications"
     query_params={}
@@ -160,7 +188,7 @@ def getSiteSleImpactedAps(mist_session:_APISession, site_id:str, scope:str, scop
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleImpactedAps
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -177,6 +205,10 @@ def getSiteSleImpactedAps(mist_session:_APISession, site_id:str, scope:str, scop
     :param int end
     :param str duration
     :param str classifier        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-aps"
     query_params={}
@@ -191,7 +223,7 @@ def getSiteSleImpactedChassis(mist_session:_APISession, site_id:str, scope:str,
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleImpactedChassis
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -208,6 +240,10 @@ def getSiteSleImpactedChassis(mist_session:_APISession, site_id:str, scope:str,
     :param int end
     :param str duration
     :param str classifier        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-chassis"
     query_params={}
@@ -222,7 +258,7 @@ def getSiteSleImpactedWiredClients(mist_session:_APISession, site_id:str, scope:
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleImpactedWiredClients
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -239,6 +275,10 @@ def getSiteSleImpactedWiredClients(mist_session:_APISession, site_id:str, scope:
     :param int end
     :param str duration
     :param str classifier        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-clients"
     query_params={}
@@ -253,7 +293,7 @@ def getSiteSleImpactedGateways(mist_session:_APISession, site_id:str, scope:str,
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleImpactedGateways
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -270,6 +310,10 @@ def getSiteSleImpactedGateways(mist_session:_APISession, site_id:str, scope:str,
     :param int end
     :param str duration
     :param str classifier        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-gateways"
     query_params={}
@@ -284,7 +328,7 @@ def getSiteSleImpactedInterfaces(mist_session:_APISession, site_id:str, scope:st
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleImpactedInterfaces
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -301,6 +345,10 @@ def getSiteSleImpactedInterfaces(mist_session:_APISession, site_id:str, scope:st
     :param int end
     :param str duration
     :param str classifier        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-interfaces"
     query_params={}
@@ -315,7 +363,7 @@ def getSiteSleImpactedSwitches(mist_session:_APISession, site_id:str, scope:str,
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleImpactedSwitches
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -332,6 +380,10 @@ def getSiteSleImpactedSwitches(mist_session:_APISession, site_id:str, scope:str,
     :param int end
     :param str duration
     :param str classifier        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-switches"
     query_params={}
@@ -346,7 +398,7 @@ def getSiteSleImpactedWirelessClients(mist_session:_APISession, site_id:str, sco
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleImpactedWirelessClients
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -363,6 +415,10 @@ def getSiteSleImpactedWirelessClients(mist_session:_APISession, site_id:str, sco
     :param int end
     :param str duration
     :param str classifier        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-users"
     query_params={}
@@ -377,7 +433,7 @@ def getSiteSleSummary(mist_session:_APISession, site_id:str, scope:str, scope_id
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleSummary
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -385,7 +441,9 @@ def getSiteSleSummary(mist_session:_APISession, site_id:str, scope:str, scope_id
     -----------
     :param str site_id
     :param str scope
-    :param str scope_id
+    :param str scope_id - * site_id if `scope`==`site`
+* device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
+* mac if `scope`==`client`
     :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
@@ -393,6 +451,10 @@ def getSiteSleSummary(mist_session:_APISession, site_id:str, scope:str, scope_id
     :param int start
     :param int end
     :param str duration        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/summary"
     query_params={}
@@ -406,7 +468,7 @@ def getSiteSleThreshold(mist_session:_APISession, site_id:str, scope:str, scope_
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSleThreshold
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -414,8 +476,14 @@ def getSiteSleThreshold(mist_session:_APISession, site_id:str, scope:str, scope_
     -----------
     :param str site_id
     :param str scope
-    :param str scope_id
+    :param str scope_id - * site_id if `scope`==`site`
+* device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
+* mac if `scope`==`client`
     :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/threshold"
     query_params={}
@@ -426,7 +494,7 @@ def replaceSiteSleThreshold(mist_session:_APISession, site_id:str, scope:str, sc
     """
     API doc: https://doc.mist-lab.fr/#operation/replaceSiteSleThreshold
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -434,8 +502,14 @@ def replaceSiteSleThreshold(mist_session:_APISession, site_id:str, scope:str, sc
     -----------
     :param str site_id
     :param str scope
-    :param str scope_id
+    :param str scope_id - * site_id if `scope`==`site`
+* device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
+* mac if `scope`==`client`
     :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/threshold"
     resp = mist_session.mist_post(uri=uri, body=body)
@@ -445,7 +519,7 @@ def updateSiteSleThreshold(mist_session:_APISession, site_id:str, scope:str, sco
     """
     API doc: https://doc.mist-lab.fr/#operation/updateSiteSleThreshold
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -453,8 +527,14 @@ def updateSiteSleThreshold(mist_session:_APISession, site_id:str, scope:str, sco
     -----------
     :param str site_id
     :param str scope
-    :param str scope_id
+    :param str scope_id - * site_id if `scope`==`site`
+* device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
+* mac if `scope`==`client`
     :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/threshold"
     resp = mist_session.mist_put(uri=uri, body=body)
@@ -464,7 +544,7 @@ def getSiteSlesMetrics(mist_session:_APISession, site_id:str, scope:str, scope_i
     """
     API doc: https://doc.mist-lab.fr/#operation/getSiteSlesMetrics
     
-    PARMS
+    PARAMS
     -----------
     :param APISession mist_session - mistapi session including authentication and Mist host information
     
@@ -472,7 +552,13 @@ def getSiteSlesMetrics(mist_session:_APISession, site_id:str, scope:str, scope_i
     -----------
     :param str site_id
     :param str scope
-    :param str scope_id        
+    :param str scope_id - * site_id if `scope`==`site`
+* device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
+* mac if `scope`==`client`        
+    
+    RETURN
+    -----------
+    :return APIResponse - response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics"
     query_params={}
